@@ -187,9 +187,15 @@ class CMISClient:
         content_filename = data.get("bestandsnaam") or cmis_doc.bestandsnaam
 
         try:
+            # Content can be empty in case of large file uploads, because the file is
+            # uploaded using `BestandsDelen`
+            # https://github.com/VNG-Realisatie/gemma-zaken/blob/master/docs/_content/standaard/documenten/index.md#opslaan-van-bestanden
+            # cmis_doc.update_content(content or BytesIO(b""), content_filename)
             if content is not None:
-                cmis_doc.update_content(content, content_filename)
-            cmis_doc.update_properties(diff_properties)
+                cmis_doc.update_content(content or BytesIO(b""), content_filename)
+
+            if diff_properties:
+                cmis_doc.update_properties(diff_properties)
         except UpdateConflictException as exc:
             # Node locked!
             raise DocumentConflictException from exc
