@@ -19,6 +19,7 @@ from drc_cmis.utils.exceptions import (
     DocumentExistsError,
     DocumentLockedException,
     DocumentNotLockedException,
+    DocumentSizeMismatchException,
     FolderDoesNotExistError,
     LockDidNotMatchException,
 )
@@ -786,6 +787,18 @@ class SOAPCMISClient(CMISClient):
                 "Document is not checked out and/or locked."
             )
 
+        # If bestandsomvang is explicitly defined, but does not match the actual size
+        # of the content, that means that the upload has not been completed yet ->
+        # the document cannot be unlocked yet
+        if (
+            not force
+            and cmis_doc.bestandsomvang
+            and cmis_doc.bestandsomvang != cmis_doc.contentStreamLength
+        ):
+            raise DocumentSizeMismatchException(
+                "`Document.bestandsomvang` does not match the actual size of the uploaded document."
+            )
+
         if constant_time_compare(cmis_doc.lock, lock) or force:
             lock_property = {
                 mapper("lock"): {
